Module: DetectorRegistry
- Defined in:
- lib/persistence_detector/detector_registry.rb
Overview
Each detector implementation adds an instance of itself to the array, $detector_registry. The persistence_detector.rb file iterates over this registry to invoke each applicable detector on the host system.